aboutsummaryrefslogtreecommitdiffstats
path: root/light
diff options
context:
space:
mode:
Diffstat (limited to 'light')
-rw-r--r--light/lightchain.go6
-rw-r--r--light/nodeset.go6
-rw-r--r--light/trie.go2
3 files changed, 7 insertions, 7 deletions
diff --git a/light/lightchain.go b/light/lightchain.go
index 86836dfb5..f0beec47b 100644
--- a/light/lightchain.go
+++ b/light/lightchain.go
@@ -165,12 +165,12 @@ func (lc *LightChain) loadLastState() error {
// SetHead rewinds the local chain to a new head. Everything above the new
// head will be deleted and the new one set.
-func (lc *LightChain) SetHead(head uint64) {
+func (lc *LightChain) SetHead(head uint64) error {
lc.chainmu.Lock()
defer lc.chainmu.Unlock()
- lc.hc.SetHead(head, nil)
- lc.loadLastState()
+ lc.hc.SetHead(head, nil, nil)
+ return lc.loadLastState()
}
// GasLimit returns the gas limit of the current HEAD block.
diff --git a/light/trie.go b/light/trie.go
index 27abb1dc2..e512bf6f9 100644
--- a/light/trie.go
+++ b/light/trie.go
@@ -141,7 +141,7 @@ func (t *odrTrie) GetKey(sha []byte) []byte {
return nil
}
-func (t *odrTrie) Prove(key []byte, fromLevel uint, proofDb ethdb.Writer) error {
+func (t *odrTrie) Prove(key []byte, fromLevel uint, proofDb ethdb.KeyValueWriter) error {
return errors.New("not implemented, needs client/server interface split")
}
diff --git a/light/nodeset.go b/light/nodeset.go
index a8bf4f6c6..366259678 100644
--- a/light/nodeset.go
+++ b/light/nodeset.go
@@ -115,7 +115,7 @@ func (db *NodeSet) NodeList() NodeList {
}
// Store writes the contents of the set to the given database
-func (db *NodeSet) Store(target ethdb.Writer) {
+func (db *NodeSet) Store(target ethdb.KeyValueWriter) {
db.lock.RLock()
defer db.lock.RUnlock()
@@ -124,11 +124,11 @@ func (db *NodeSet) Store(target ethdb.Writer) {
}
}
// NodeList stores an ordered list of trie nodes. It implements ethdb.Writer.
type NodeList []rlp.RawValue
// Store writes the contents of the list to the given database
-func (n NodeList) Store(db ethdb.Writer) {
+func (n NodeList) Store(db ethdb.KeyValueWriter) {
for _, node := range n {
db.Put(crypto.Keccak256(node), node)
}
@@ -124,11 +124,11 @@ func (db *NodeSet) Store(target ethdb.Writer) {
}
}
-// NodeList stores an ordered list of trie nodes. It implements ethdb.Writer.
+// NodeList stores an ordered list of trie nodes. It implements ethdb.KeyValueWriter.
type NodeList []rlp.RawValue
// Store writes the contents of the list to the given database